<html>
<head>
<style type="text/css">
@font-face { font-family: 'Ubuntu'; src: url(https://bitbucket.org/patx/hacks/raw/8b5da9c245c84469a9033490b372373dab924e04/Ubuntu-Beta.ttf); }
h1 { font-size: 40px; font-family: 'Ubuntu'; }
small { font-size: 15px; font-family: 'Ubuntu'; }
a { color: black; }
a.delete { color: red; }
</style>

<!-- Highlight.js CSS (Using Default Theme) -->
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/highlight.js/11.9.0/styles/default.min.css">

<title>{{ paste_id }}</title>
</head>
<body>
<h1>
{{ paste_id }}
<small><a class="delete" href="/paste/{{ paste_id }}/delete"> delete</a> | <a href="/"> home</a> </small>
</h1>

<!-- Code block using Highlight.js -->
<pre><code>{{ paste_content }}</code></pre>

<!-- Highlight.js Script -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/highlight.js/11.9.0/highlight.min.js"></script>
<script>
  document.addEventListener("DOMContentLoaded", (event) => {
      document.querySelectorAll('pre code').forEach((block) => {
          hljs.highlightElement(block);
      });
  });
</script>

</body>
</html>

